# Units

* Every quantity in re:mobidyc must have a unit.
* Any quantity will be converted into a coherent derived units of the SI (International System of Units).
* A temperature will be converted into Kelvin.


## Length
The base unit is meter [m].

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `Mm` | | 10^6 [m] |
| `km` | | 10^3 [m] |
| `m` | | |
| `dm` | | 10^-1 [m] |
| `cm` | | 10^-2 [m] |
| `mm` | | 10^-3 [m] |
| `µm` | `microm` `micrometer`| 10^-6 [m] |
| `nm` | `nanom` `nanometer`| 10^-9 [m] |
| `pm` | `picom` `picometer`| 10^-12 [m] |
| `mi` | `mile` `miles`| 1609.344[m] |
| `yd` | `yard` `yards`| 0.9144[m] |
| `ft` | `foot` `feet`| 0.3048[m] |
| `in` | `inch` `inches`| 0.0254[m] |

## Mass
The base unit is meter [kg].

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `t` | `Mg` | 10^3 [kg] |
| `kg` | | |
| `g` |  | 10^-3 [kg] |
| `mg` | `millig` `milligram`  | 10^-6 [kg] |
| `µg` |  `microg` `microgram`| 10^-9 [kg] |
| `ng` |  `nanog` `nanogram`| 10^-12 [kg] |
| `pg` |  `picog` `picogram`| 10^-15 [kg] |
| `fg` |  `femtog` `femtogram`| 10^-18 [kg] |
| `lb` | | 0.45359237 [kg] |
| `oz` | | 0.028349523125 [kg] |
| `gr` | | 0.00006479891 [kg] |

## Time
The base uit is second [s].

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `year` | `y` `yr` `a` `years` | 31557600 [s] |
| `month31` | `mo31` `months31` | 2678400 [s] |
| `month` | `mo` `months` `mo30` `month30` `months30` | 2592000 [s] |
| `week` | `w` `weeks` | 604800 [s] |
| `day` | `days` | 86400 [s] |
| `h` | `hour` `hours` | 3600 [s] |
| `min` | `mins` `minute` `minutes` | 60 [s] |
| `s` | `sec` `secs` `ss` | |
| `ms` | `msec` | 10^-3 [s] |
| `µs` | `µsec` `micros` `micross` | 10^-6 [s] |

## Temperature
Although SI defines the base unit be Kelvin [K], re:mobidyc handles Celsius [°C] and Fahrenheit [°F] as base units.
The three units are handled as independent dimensions and no automatic conversions will be made.

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `K` | `K` `Kelvin` | |
| `°C` | `°C` `℃` `DegreeC` `Celsius` | |
| `°F` | `F` `℉` `DegreeF` `Fahrenheit` | |

## Angle
The coherent derived unit is radian [rad] ([1]).

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `rad` | `㎭` | |
| `degree` | `degrees` `°` | π / 180 [rad] |

## Amount of substance
The base unit is mol [mol].

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `mol` | `㏖` | |

## Area
The coherent derived unit is square meter [m^2].

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `ha` | | 10^4 [m^2] |
| `a` | | 10^2 [m^2] |
| `m^2` | `m2` | |
| `ac` | | 4046.8564224 [m^2] |

## Volume
The coherent derived unit is cubic meter [m^3].
| symbol | alternatives | definition |
| -----|------- | ----------- |
| `GL` | `Gl` `Gℓ` | 10^6 [m^3] |
| `ML` | `Ml` `Mℓ` | 10^3 [m^3] |
| `kL` | `kl` `kℓ` `㎘` | 1 [m^3] |
| `m^3`| `m3` | |
|`hL` | `hl` `hℓ` | 10^-1 [m^3] |
| `daL` | `dal` `daℓ` | 10^-2 [m^3] |
| `L` | `l` `ℓ` `litre` `liter` | 10^-3 [m^3] |
| `dL` | `dl` `dℓ` | 10^-4 [m^3] |
| `mL` | `mℓ` `㎖`  | 10^-6 [m^3] |
| `µL` | `µl` `µℓ` | 10^-9 [m^3] |

## Force
The coherent derived unit is newton [N] ([kg * m / s^2]).

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `N` | | |
| `kgf` | |  9.8 [N] |
| `dyn` | | 10^-5 [N] |
| `lbf` | | 4.4482216152605 [N] |
| `pdl` | | 0.13825495437 [N] |
| `sn` | | 10^3 [N] |

## Pressure
The coherent derived unit is pascal [Pa] ([kg • m / (s^2 • m^2)]).

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `Pa` | | |
| `daPa` | |  10 [Pa] |
| `hPa` | | 10^2 [Pa] |
| `kPa` | |  10^3 [Pa] |
| `MPa` | |  10^6 [Pa] |
| `GPa` | | 10^9 [Pa] |
| `dPa` | | 10^-1 [Pa] |
| `cPa` | | 10^-2 [Pa] |
| `mPa` | | 10^-3 [Pa] |
| `μPa` | | 10^-6 [Pa] |
| `at` | | 98066.5 [Pa] |
| `psi` | | 6894.757 [Pa] |
| `Torr` | | 133.322 [Pa] |
| `atm` | | 101325 [Pa] |
| `bar` | | 100000 [Pa] |

## Energy
The coherent derived unit is Joule [J] ([kg • m^2 / s^2]).

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `J` | | |
| `cal` | | 4.184 [J] |
| `kcal` | | 4.184 * 10^3 [J] |

## Power
The coherent derived unit is Watt [W] ([kg • m^2 / s^3]).

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `W` | `㍗` | |
| `kW` | `㎾` `㌗`| 10^3 [W] |
| `MW` | `㎿`| 10^6 [W] |
| `GW` | | 10^9 [W] |
| `mW` | `㎽`| 10^-3 [W] |
| `μW` | `㎼`| 10^-6 [W] |
| `nW` | `㎻`| 10^-9 [W] |
| `pW` | `㎺`| 10^-12 [W] |
| `PS` | | 735.5 [W] |
| `HP` | `BHP` `㏋`| 745 [W] |

## Probability
Although there is no unit for probability, we define the following for convenience.

| symbol | alternatives | definition |
| -----|------- | ----------- |
| `%` | `percent` |  10^-2 [] |
